pub trait QeiChannel: SealedQeiChannel { }Expand description
Marker trait for a timer channel eligible for use with QEI.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait QeiChannel: SealedQeiChannel { }Marker trait for a timer channel eligible for use with QEI.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".